# LangChain with Chatopera Tool Calling

[https://github.com/chatopera/langchain-chatopera](https://github.com/chatopera/langchain-chatopera)

build Agent Services by integrating chatopera cloud services with langchain via tool calling.


## Usage

```
pip install langchain_chatopera
```

## Contribute



# License
[LICENSE](./LICENSE)